# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangorrd', '0003_auto_20151010_2128'),
    ]

    operations = [
        migrations.AddField(
            model_name='graph',
            name='background_color',
            field=models.CharField(default='dddddd', max_length=6, verbose_name='Background Color #'),
        ),
        migrations.AddField(
            model_name='graph',
            name='canvas_color',
            field=models.CharField(default='ffffff', max_length=6, verbose_name='Canvas Color #'),
        ),
        migrations.AlterField(
            model_name='graph',
            name='color',
            field=models.CharField(default='ff0000', max_length=6, verbose_name='Color #'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangorrd', '0002_auto_20151010_1834'),
    ]

    operations = [
        migrations.AddField(
            model_name='graph',
            name='border',
            field=models.IntegerField(default=0, help_text='Border width in pixels', verbose_name='Border'),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='graph',
            name='full_size_mode',
            field=models.BooleanField(default=False, help_text='If true, the width and height specify the final dimensions of the output image', verbose_name='Full size mode'),
        ),
        migrations.AddField(
            model_name='graph',
            name='lazy',
            field=models.BooleanField(default=False, help_text='Only generate the graph if the current graph is out of date or not existent.', verbose_name='Lazy'),
        ),
        migrations.AddField(
            model_name='graph',
            name='slope_mode',
            field=models.BooleanField(default=False, verbose_name='Slope mode'),
        ),
        migrations.AlterField(
            model_name='datasource',
            name='rrd',
            field=models.ForeignKey(to='djangorrd.RRD', verbose_name='RRD', related_name='dss'),
        ),
        migrations.AlterField(
            model_name='rra',
            name='cf',
            field=models.CharField(choices=[('AVERAGE', 'AVERAGE'), ('MINIMUM', 'MINIMUM'), ('MAXIMUM', 'MAXIMUM'), ('LAST', 'LAST')], verbose_name='Consolidation Function (CF)', max_length=32),
        ),
        migrations.AlterField(
            model_name='rra',
            name='rrd',
            field=models.ForeignKey(to='djangorrd.RRD', verbose_name='RRD', related_name='rras'),
        ),
        migrations.AlterField(
            model_name='rra',
            name='step',
            field=models.IntegerField(verbose_name='Steps'),
        ),
        migrations.AlterField(
            model_name='rra',
            name='xff',
            field=models.FloatField(verbose_name='Xfiles Factor (XFF)'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorrd', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rrd',
            name='start',
            field=models.DateTimeField(blank=True, null=True, verbose_name='Start time', help_text='Start time (current time by default)'),
        ),
        migrations.AlterField(
            model_name='rrd',
            name='step',
            field=models.IntegerField(blank=True, null=True, verbose_name='Step', help_text='Step in seconds (300 by default)'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations


class Migration(migrations.Migration):

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='DataSource',
            fields=[
                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
                ('name', models.CharField(verbose_name='Variable Name', max_length=255)),
                ('dst', models.CharField(verbose_name='Data Source Type', max_length=32, choices=[('COUNTER', 'COUNTER'), ('DERIVE', 'DERIVE'), ('ABSOLUTE', 'ABSOLUTE'), ('GAUGE', 'GAUGE')])),
                ('heartbeat', models.IntegerField(null=True, verbose_name='Heartbeat', blank=True)),
                ('min', models.IntegerField(null=True, verbose_name='Minimum value', blank=True)),
                ('max', models.IntegerField(null=True, verbose_name='Maximum value', blank=True)),
            ],
            options={
                'verbose_name_plural': 'Data Sources',
                'verbose_name': 'Data Source',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='Graph',
            fields=[
                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
                ('name', models.CharField(unique=True, verbose_name='Name', max_length=255)),
                ('title', models.CharField(verbose_name='Title', max_length=255)),
                ('vertical_label', models.CharField(verbose_name='Vertical Label', max_length=255)),
                ('period', models.IntegerField(verbose_name='Period', help_text='Period in seconds')),
                ('color', models.CharField(verbose_name='Color #', max_length=6)),
                ('width', models.IntegerField(verbose_name='Width', help_text='Width in pixels')),
                ('height', models.IntegerField(verbose_name='Height', help_text='Height in pixels')),
            ],
            options={
                'verbose_name_plural': 'RR Graphs',
                'verbose_name': 'RR Graph',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='RRA',
            fields=[
                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
                ('cf', models.CharField(verbose_name='Consolidation Function', max_length=32, choices=[('AVERAGE', 'AVERAGE'), ('MINIMUM', 'MINIMUM'), ('MAXIMUM', 'MAXIMUM'), ('LAST', 'LAST')])),
                ('xff', models.FloatField(verbose_name='XFF')),
                ('step', models.IntegerField(verbose_name='Step')),
                ('rows', models.IntegerField(verbose_name='Rows')),
            ],
            options={
                'verbose_name_plural': 'RR Archives',
                'verbose_name': 'RR Archive',
            },
            bases=(models.Model,),
        ),
        migrations.CreateModel(
            name='RRD',
            fields=[
                ('id', models.AutoField(primary_key=True, verbose_name='ID', auto_created=True, serialize=False)),
                ('name', models.TextField(unique=True, verbose_name='RRD Name')),
                ('start', models.DateTimeField(null=True, verbose_name='Start time', blank=True)),
                ('step', models.IntegerField(verbose_name='Step', help_text='Step in seconds')),
            ],
            options={
                'verbose_name_plural': 'RR Databases',
                'verbose_name': 'RR Database',
            },
            bases=(models.Model,),
        ),
        migrations.AddField(
            model_name='rra',
            name='rrd',
            field=models.ForeignKey(related_name='rras', verbose_name='RRD Database', to='djangorrd.RRD'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='graph',
            name='rrd',
            field=models.ForeignKey(related_name='graphs', verbose_name='RRD Database', to='djangorrd.RRD'),
            preserve_default=True,
        ),
        migrations.AddField(
            model_name='datasource',
            name='rrd',
            field=models.ForeignKey(related_name='dss', verbose_name='RRD Database', to='djangorrd.RRD'),
            preserve_default=True,
        ),
    ]



# Copyright (C) 2015 Okami, okami@fuzetsu.info

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 3
# of the License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.

from setuptools import setup


setup(**{
    'name': 'django-rrd',
    'version': '0.0.9',
    'author': 'Okami',
    'author_email': 'okami@fuzetsu.info',
    'description': 'Web frontend to RRDtool based on Django',
    'license': 'GPLv3',
    'keywords': 'django rrd rrdtool',
    'url': 'https://sourceforge.net/p/django-rrd/wiki/',
    'packages': [
        'djangorrd',
        'djangorrd.migrations',
        'djangorrd.management',
        'djangorrd.management.commands',
    ],
    'long_description': '',
    'classifiers': [
        'Development Status :: 3 - Alpha',
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Framework :: Django',
    ],
    'install_requires': [
        'Django >= 1.9.2',
        'python-rrdtool >= 1.4.7',
    ],
})
